@@ -5,6 +5,7 @@ pub use crate::rearrange_spec::*;
 pub use crate::rrfs::*;
 pub use crate::smallvec::Sv;
 pub use crate::tensor_util::*;
-pub use crate::uuid;
+pub use crate::uuid::uuid;
 pub use crate::*;
 pub use std::iter::zip;
+pub use uuid::Uuid;
