@@ -53,7 +53,7 @@ pub fn add_flatten_once(add: &Add) -> Option<Add> {
     if !did_anything {
         return None;
     }
-    Some(Add::try_new(new_operands, add.name_cloned()).unwrap())
+    Some(Add::new(new_operands, add.name_cloned()))
 }
 
 #[pyfunction]
@@ -69,7 +69,7 @@ pub fn add_collapse_scalar_inputs(add: &Add) -> Option<Add> {
             non_scalar_inputs.iter().map(|x| x.clone().into()).collect();
         let new_scalar_input = ScalarConstant::new(new_scalar, add.info().shape.clone(), None).rc();
         new_inputs.push(new_scalar_input);
-        Some(Add::try_new(new_inputs, add.name_cloned()).unwrap())
+        Some(Add::new(new_inputs, add.name_cloned()))
     }
 }
 
@@ -94,7 +94,7 @@ pub fn add_elim_zeros(add: &Add) -> Option<Add> {
     if !did_anything {
         None
     } else {
-        Some(Add::try_new(new_operands, add.name_cloned()).unwrap())
+        Some(Add::new(new_operands, add.name_cloned()))
     }
 }
 
@@ -120,7 +120,7 @@ pub fn add_deduplicate(add: &Add) -> Option<Add> {
                 }
             })
             .collect();
-        Some(Add::try_new(deduped_inputs, add.name_cloned()).unwrap())
+        Some(Add::new(deduped_inputs, add.name_cloned()))
     }
 }
 
@@ -240,21 +240,18 @@ pub fn einsum_flatten_once(einsum: &Einsum) -> Option<Einsum> {
         return None;
     }
     let with_ints_same = make_einsum_ints_same_one_layer(einsum);
-    Some(
-        Einsum::try_new(
-            with_ints_same
-                .args
-                .into_iter()
-                .flat_map(|(node, ints)| match &*node.0 {
-                    Circuit::Einsum(einsum) => einsum.args.clone(),
-                    _ => vec![(node, ints)],
-                })
-                .collect(),
-            with_ints_same.out_axes,
-            None,
-        )
-        .unwrap(),
-    )
+    Some(Einsum::new(
+        with_ints_same
+            .args
+            .into_iter()
+            .flat_map(|(node, ints)| match &*node.0 {
+                Circuit::Einsum(einsum) => einsum.args.clone(),
+                _ => vec![(node, ints)],
+            })
+            .collect(),
+        with_ints_same.out_axes,
+        None,
+    ))
 }
 
 /// nests einsum (similar to "rearrange_muls") according to an einops-style path with recycled IDs
@@ -294,9 +291,7 @@ pub fn einsum_nest_path(einsum: &Einsum, path: Vec<Vec<usize>>) -> Einsum {
             }
         };
         stack.push((
-            Einsum::try_new(args_here, outer_indices.clone(), None)
-                .unwrap()
-                .rc(),
+            Einsum::nrc(args_here, outer_indices.clone(), None),
             outer_indices,
         ))
     }
@@ -475,14 +470,11 @@ pub fn index_elim_identity(index: &Index) -> Option<CircuitRc> {
 #[pyfunction]
 pub fn index_fuse(index: &Index) -> Option<Index> {
     index.node.as_index().and_then(|inner| {
-        Some(
-            Index::try_new(
-                inner.node.clone(),
-                compose(&index.index, &inner.index)?,
-                index.name_cloned(),
-            )
-            .unwrap(),
-        )
+        Some(Index::new(
+            inner.node.clone(),
+            compose(&index.index, &inner.index)?,
+            index.name_cloned(),
+        ))
     })
 }
 
@@ -616,12 +608,11 @@ pub fn generalfunction_pull_removable_axes(node: &GeneralFunction) -> Option<Cir
     if removable_batchable_inp.is_empty() {
         return None;
     }
-    let new_generalfunction = GeneralFunction::try_new(
+    let new_generalfunction = GeneralFunction::new(
         vec![remove_axes(&node.nodes[0], &removable_batchable_inp).unwrap()],
         node.spec.clone(),
         node.name_cloned(),
-    )
-    .unwrap();
+    );
     let removable_batchable_out: HashSet<usize> = removable_batchable_inp
         .iter()
         .map(|x| x + node.info().rank() - node.nodes[0].info().rank())
@@ -651,15 +642,14 @@ pub fn concat_pull_removable_axes(node: &Concat) -> Option<CircuitRc> {
             .iter()
             .filter(|i| **i < node.axis)
             .count();
-    let new_node = Concat::try_new(
+    let new_node = Concat::new(
         node.nodes
             .iter()
             .map(|node| remove_axes(node, &removable_non_axis).unwrap())
             .collect(),
         new_axis,
         node.name_cloned(),
-    )
-    .unwrap();
+    );
     Some(Rearrange::nrc_elim_identity(
         new_node.rc(),
         RearrangeSpec::unremove_axes(&removable_non_axis, &node.info().shape),
@@ -855,7 +845,7 @@ pub fn add_make_broadcasts_explicit(add: &Add) -> Option<Add> {
     if !did_anything {
         return None;
     }
-    Some(Add::try_new(new_nodes, add.name_cloned()).unwrap())
+    Some(Add::new(new_nodes, add.name_cloned()))
 }
 
 /// should return result instead
@@ -880,7 +870,7 @@ pub fn distribute(einsum: &Einsum, operand_idx: usize, do_broadcasts: bool) -> O
                 Einsum::nrc(new_args, einsum.out_axes.clone(), None)
             })
             .collect();
-        Some(Add::try_new(summands, None).unwrap())
+        Some(Add::new(summands, None))
     })
 }
 
@@ -933,14 +923,14 @@ pub fn einsum_of_permute_merge(einsum: &Einsum) -> Option<Einsum> {
     if !did_anything {
         return None;
     }
-    Some(Einsum::try_new(new_args, einsum.out_axes.clone(), None).unwrap())
+    Some(Einsum::new(new_args, einsum.out_axes.clone(), None))
 }
 
 #[pyfunction]
 pub fn permute_of_einsum_merge(rearrange: &Rearrange) -> Option<Einsum> {
     rearrange.spec.get_fwd_permutation().and_then(|perm| {
         rearrange.node.as_einsum().map(|einsum| {
-            Einsum::try_new(
+            Einsum::new(
                 einsum.args.clone(),
                 inverse_permutation(&perm)
                     .iter()
@@ -948,7 +938,6 @@ pub fn permute_of_einsum_merge(rearrange: &Rearrange) -> Option<Einsum> {
                     .collect(),
                 None,
             )
-            .unwrap()
         })
     })
 }
@@ -992,7 +981,7 @@ pub fn einsum_merge_scalars(einsum: &Einsum) -> Option<Einsum> {
     if scalar_mul != 1.0 {
         new_args.push((ScalarConstant::new(scalar_mul, sv![], None).rc(), sv![]))
     }
-    Some(Einsum::try_new(new_args, einsum.out_axes.clone(), None).unwrap())
+    Some(Einsum::new(new_args, einsum.out_axes.clone(), None))
 }
 
 /// We want to turn einsum ab->b, where a is concat, to be Add [a1b->b, a2b->b...]
@@ -1056,7 +1045,7 @@ pub fn einsum_concat_to_add(einsum: &Einsum) -> Option<Add> {
             Einsum::nrc(new_args, einsum.out_axes.clone(), None)
         })
         .collect();
-    Some(Add::try_new(inner_einsum, None).unwrap())
+    Some(Add::new(inner_einsum, None))
 }
 
 #[pyfunction]
@@ -1084,16 +1073,11 @@ pub fn index_split_axes(node: &Index, top_axes: std::collections::HashSet<usize>
             }
         }
     }
-    Some(
-        Index::try_new(
-            Index::try_new(node.node.clone(), TensorIndex(bottom), None)
-                .unwrap()
-                .rc(),
-            TensorIndex(top),
-            None,
-        )
-        .unwrap(),
-    )
+    Some(Index::new(
+        Index::nrc(node.node.clone(), TensorIndex(bottom), None),
+        TensorIndex(top),
+        None,
+    ))
 }
 
 #[pyfunction]
@@ -1101,12 +1085,11 @@ pub fn rearrange_fuse(node: &Rearrange) -> Option<Rearrange> {
     node.node.as_rearrange().and_then(|inner| {
         RearrangeSpec::fuse(&inner.spec, &node.spec)
             .map(|spec| {
-                Rearrange::try_new(
+                Rearrange::new(
                     inner.node.clone(),
                     spec.canonicalize(true),
                     node.name_cloned(),
                 )
-                .unwrap()
             })
             .ok()
     })
@@ -1469,16 +1452,14 @@ pub fn concat_repeat_to_rearrange(concat: &Concat) -> Option<Concat> {
     if !did_anything {
         return None;
     }
-    Some(Concat::try_new(new_nodes, concat.axis, concat.name_cloned()).unwrap())
+    Some(Concat::new(new_nodes, concat.axis, concat.name_cloned()))
 }
 
 #[test]
 fn basic_check_same_concat_shape() {
     let a = Symbol::new_with_random_uuid(sv![2, 3, 4, 5, 6], None).rc();
-    let out = concat_repeat_to_rearrange(
-        &Concat::try_new(vec![a.clone(), a.clone(), a], 3, None).unwrap(),
-    )
-    .unwrap();
+    let out =
+        concat_repeat_to_rearrange(&Concat::new(vec![a.clone(), a.clone(), a], 3, None)).unwrap();
     assert_eq!(out.info().shape[3], 15)
 }
 
@@ -1546,17 +1527,15 @@ pub fn add_outer_product_broadcasts_on_top(add: &Add) -> Option<Add> {
     let new_operands = outer_product_sets
         .iter()
         .map(|operand_set_bitmask| {
-            Add::try_new(
+            Add::nrc(
                 BitIter::from(*operand_set_bitmask)
                     .map(|i| add.nodes[i].clone())
                     .collect(),
                 None,
             )
-            .unwrap()
-            .rc()
         })
         .collect();
-    Some(Add::try_new(new_operands, None).unwrap())
+    Some(Add::new(new_operands, None))
 }
 
 /// returns None if sub isn't subset
@@ -1622,8 +1601,7 @@ pub fn add_fuse_scalar_multiples(add: &Add) -> Option<Add> {
                     .collect();
 
                     (
-                        Einsum::try_new(no_scalar_children, e.out_axes.clone(), e.name_cloned())
-                            .unwrap(),
+                        Einsum::new(no_scalar_children, e.out_axes.clone(), e.name_cloned()),
                         scalar,
                         new_name,
                     )
@@ -1666,12 +1644,12 @@ pub fn add_fuse_scalar_multiples(add: &Add) -> Option<Add> {
                 let out_axes = einsum.out_axes;
                 let mut v = einsum.args;
                 v.push((ScalarConstant::new(scalar, sv![], scalar_name).rc(), sv![]));
-                Einsum::try_new(v, out_axes, name).unwrap().rc()
+                Einsum::nrc(v, out_axes, name)
             }
         })
         .collect();
 
-    Some(Add::try_new(nodes, add.name_cloned()).unwrap())
+    Some(Add::new(nodes, add.name_cloned()))
 }
 
 #[pyfunction]
@@ -1681,18 +1659,15 @@ pub fn einsum_permute_to_rearrange(einsum: &Einsum) -> Option<Rearrange> {
         && is_unique(&einsum.out_axes)
         && is_unique(&einsum.args[0].1)
     {
-        return Some(
-            Rearrange::try_new(
-                einsum.args[0].0.clone(),
-                RearrangeSpec {
-                    input_ints: einsum.args[0].1.iter().map(|z| sv![*z]).collect(),
-                    output_ints: einsum.out_axes.iter().map(|z| sv![*z]).collect(),
-                    int_sizes: sv![OpSize::NONE;einsum.info().rank()],
-                },
-                einsum.name_cloned(),
-            )
-            .unwrap(),
-        );
+        return Some(Rearrange::new(
+            einsum.args[0].0.clone(),
+            RearrangeSpec {
+                input_ints: einsum.args[0].1.iter().map(|z| sv![*z]).collect(),
+                output_ints: einsum.out_axes.iter().map(|z| sv![*z]).collect(),
+                int_sizes: sv![OpSize::NONE;einsum.info().rank()],
+            },
+            einsum.name_cloned(),
+        ));
     }
     None
 }
