@@ -3,10 +3,13 @@ use super::Einsum;
 use super::{
     named_axes::get_axis_leaves, prelude::*, Index, ModuleNodeArgSpec, ModuleNodeSpec, Symbol,
 };
+
 use crate::circuit::algebraic_rewrite::einsum_nest_optimize;
 use crate::circuit::circuit_optimizer::OptimizationSettings;
 use crate::circuit::named_axes::axis_of_name;
-use crate::circuit::{deep_map_op, visit_circuit, visit_circuit_with_parents, Concat, EinsumAxes};
+use crate::circuit::{
+    deep_map_op, visit_circuit_unwrap, visit_circuit_with_parents, Concat, EinsumAxes,
+};
 use crate::circuit::{deep_map_unwrap, named_axes::set_named_axes, CircResult, ModuleNode};
 use crate::set_cover::set_cover;
 use crate::tensor_util::TensorAxisIndex;
@@ -196,7 +199,7 @@ pub fn batch_einsum(einsum: &Einsum, context: &mut OptimizationContext) -> CircR
 
     nested_big.compiler_print();
     let mut intermediates_above_mem = vec![];
-    visit_circuit(nested_big.clone().rc(), |c| {
+    visit_circuit_unwrap(nested_big.clone().rc(), |c| {
         if c.info().numel_usize() > max_single_mem {
             intermediates_above_mem.push(c);
         }
