@@ -306,7 +306,7 @@ impl Einsum {
     #[cfg(feature = "real-pyo3")]
     #[new]
     #[args(args = "*", out_axes, name)]
-    fn py_new(
+    fn new_py(
         args: Vec<(CircuitRc, EinsumAxes)>,
         out_axes: EinsumAxes,
         name: Option<String>,
@@ -552,7 +552,7 @@ impl Add {
 impl Add {
     #[cfg(feature = "real-pyo3")]
     #[new]
-    fn new(nodes: Vec<CircuitRc>, name: Option<String>) -> PyResult<PyClassInitializer<Self>> {
+    fn new_py(nodes: Vec<CircuitRc>, name: Option<String>) -> PyResult<PyClassInitializer<Self>> {
         let out = Self::try_new(nodes, name)?;
 
         Ok(out.into_init())
@@ -880,7 +880,7 @@ impl CircuitNodeAutoName for Rearrange {
 impl Rearrange {
     #[cfg(feature = "real-pyo3")]
     #[new]
-    fn new(
+    fn new_py(
         node: CircuitRc,
         spec: RearrangeSpec,
         name: Option<String>,
@@ -1079,7 +1079,7 @@ impl CircuitNodeAutoName for Index {
 impl Index {
     #[cfg(feature = "real-pyo3")]
     #[new]
-    fn new(
+    fn new_py(
         node: CircuitRc,
         index: TensorIndex,
         name: Option<String>,
@@ -1256,7 +1256,7 @@ impl CircuitNodeAutoName for Concat {
 impl Concat {
     #[cfg(feature = "real-pyo3")]
     #[new]
-    fn new(
+    fn new_py(
         nodes: Vec<CircuitRc>,
         axis: usize,
         name: Option<&str>,
@@ -1420,7 +1420,7 @@ impl CircuitNodeAutoName for Scatter {
 impl Scatter {
     #[cfg(feature = "real-pyo3")]
     #[new]
-    fn new(
+    fn new_py(
         node: CircuitRc,
         index: TensorIndex,
         shape: Shape,
