@@ -381,15 +381,14 @@ pub fn deep_heuristic_nest_adds(circ: CircuitRc) -> CircuitRc {
     let mut intersections: HashSet<Add> = HashSet::new();
     for circ in &seen_adds {
         for circ2 in &seen_adds {
-            let intersection = Add::try_new(
+            let intersection = Add::new(
                 circ.nodes
                     .iter()
                     .filter(|x| circ2.nodes.contains(x))
                     .cloned()
                     .collect(),
                 None,
-            )
-            .unwrap();
+            );
             if intersection.nodes.len() >= 2 && &intersection != circ && &intersection != circ2 {
                 intersections.insert(intersection);
             }
@@ -431,9 +430,9 @@ pub fn deep_heuristic_nest_adds(circ: CircuitRc) -> CircuitRc {
 
 pub fn add_nest_ltr(add: &Add) -> Add {
     let (l, r) = add.nodes.split_at(2.min(add.nodes.len()));
-    let base = Add::try_new(l.to_vec(), None).unwrap();
+    let base = Add::new(l.to_vec(), None);
     r.iter().fold(base, |acc, x| {
-        Add::try_new(vec![acc.rc(), x.clone()], None).unwrap()
+        Add::new(vec![acc.rc(), x.clone()], None)
     })
 }
 
