@@ -61,7 +61,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
                         // have to rearrange
                         let explicit_add =
                             add_make_broadcasts_explicit(child).unwrap_or(child.clone());
-                        let new_add = Add::try_new(
+                        let new_add = Add::nrc(
                             explicit_add
                                 .nodes
                                 .iter()
@@ -70,9 +70,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
                                 })
                                 .collect(),
                             None,
-                        )
-                        .unwrap()
-                        .rc();
+                        );
                         did_anything = true;
                         return (new_add, ints.into_iter().unique().cloned().collect());
                     }
@@ -120,7 +118,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
                                 .collect();
                             // can't just use new_trace bc which one gets eliminated is determined by output, not input
                             // so for instance `aba` might go to `ba` instead of normal `ab`
-                            let new_trace = Einsum::try_new(
+                            let new_trace = Einsum::nrc(
                                 vec![(child.node.clone(), thingy.clone())],
                                 (0..child.node.info().rank())
                                     .filter(|i| {
@@ -129,17 +127,13 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
                                     .map(|i| thingy[i])
                                     .collect(),
                                 None,
-                            )
-                            .unwrap()
-                            .rc();
+                            );
 
-                            let new_rearrange = Rearrange::try_new(
+                            let new_rearrange = Rearrange::nrc(
                                 new_trace,
                                 child.spec.filter_all_tuples(&tuples_to_remove),
                                 None,
-                            )
-                            .unwrap()
-                            .rc();
+                            );
                             let up_axes = intersected_deduped
                                 .iter()
                                 .map(|i| {
@@ -197,7 +191,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
                                 })
                                 .collect();
                             return (
-                                Index::try_new(
+                                Index::nrc(
                                     new_trace,
                                     TensorIndex(
                                         intersected_ints_input_deduped
@@ -212,9 +206,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
                                             .collect(),
                                     ),
                                     None,
-                                )
-                                .unwrap()
-                                .rc(),
+                                ),
                                 up_axes,
                             );
                         }
@@ -230,7 +222,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
                                 .iter()
                                 .position(|x| *x == concat_axis_int)
                                 .unwrap();
-                            let new_concat = Concat::try_new(
+                            let new_concat = Concat::nrc(
                                 child
                                     .nodes
                                     .iter()
@@ -241,9 +233,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
                                     .collect(),
                                 new_concat_axis,
                                 None,
-                            )
-                            .unwrap()
-                            .rc();
+                            );
                             let up_axes = deduped_here
                                 .iter()
                                 .map(|x| {
@@ -267,7 +257,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
     if !did_anything {
         return None;
     }
-    Some(Einsum::try_new(new_args, einsum.out_axes.clone(), einsum.name_cloned()).unwrap())
+    Some(Einsum::new(new_args, einsum.out_axes.clone(), einsum.name_cloned()))
 }
 
 #[pyfunction]
@@ -307,12 +297,12 @@ pub fn add_pull_diags(add: &Add) -> Option<Einsum> {
     if overall_diags_deduped.len() == overall_diags.len() {
         return None;
     }
-    let new_add = Add::try_new(
+    let new_add = Add::nrc(
         add.nodes_and_rank_differences()
             .iter()
             .map(|(node, rdif)| {
                 let ein = unwrap!(&***node, Circuit::Einsum);
-                Einsum::try_new(
+                Einsum::nrc(
                     ein.args.clone(),
                     overall_diags[*rdif..]
                         .iter()
@@ -324,13 +314,9 @@ pub fn add_pull_diags(add: &Add) -> Option<Einsum> {
                         .collect(),
                     None,
                 )
-                .unwrap()
-                .rc()
             })
             .collect(),
         add.name_cloned(),
-    )
-    .unwrap()
-    .rc();
+    );
     Some(Einsum::new_diag(new_add, overall_diags, None))
 }
