@@ -38,7 +38,7 @@ pub fn einsum_elim_removable_axes_weak(einsum: &Einsum) -> Option<Einsum> {
         return None;
     }
     return Some(
-        Einsum::try_new(
+        Einsum::new(
             einsum
                 .args
                 .iter()
@@ -71,8 +71,7 @@ pub fn einsum_elim_removable_axes_weak(einsum: &Einsum) -> Option<Einsum> {
                 .collect(),
             einsum.out_axes.clone(),
             einsum.name_cloned(),
-        )
-        .unwrap(),
+        ),
     );
 }
 
@@ -107,7 +106,7 @@ pub fn add_elim_removable_axes_weak(add: &Add) -> Option<Add> {
         return None;
     }
     Some(
-        Add::try_new(
+        Add::new(
             add.nodes_and_rank_differences()
                 .iter()
                 .enumerate()
@@ -138,8 +137,7 @@ pub fn add_elim_removable_axes_weak(add: &Add) -> Option<Add> {
                 })
                 .collect(),
             add.name_cloned(),
-        )
-        .unwrap(),
+        ),
     )
 }
 
