@@ -9,6 +9,8 @@ use crate::circuit::{
     StoredCumulantVar,
 };
 use crate::hashmaps::FxHashMap as HashMap;
+use crate::lru_cache::TensorCacheRrfs;
+use crate::py_types::Tensor;
 use crate::pyo3_prelude::*;
 use crate::tensor_util::TorchDeviceDtypeOp;
 use once_cell::sync::Lazy;
@@ -23,14 +25,36 @@ use uuid::Uuid;
     module_spec_map = "HashMap::new()",
     reference_circuits = "HashMap::new()",
     tensors_as_random = "false",
-    tensors_as_random_device_dtype = "TorchDeviceDtypeOp{device:None,dtype:None}"
+    tensors_as_random_device_dtype = "TorchDeviceDtypeOp{device:None,dtype:None}",
+    tensor_getter = "None"
 )]
+#[pyo3(name = "parse_compiler_repr_bijection")]
+pub fn parse_compiler_repr_bijection_py(
+    string: &str,
+    module_spec_map: HashMap<String, ModuleNodeSpec>,
+    reference_circuits: HashMap<String, CircuitRc>,
+    tensors_as_random: bool,
+    tensors_as_random_device_dtype: TorchDeviceDtypeOp,
+    tensor_cache: Option<TensorCacheRrfs>,
+) -> Result<CircuitRc, CircuitConstructionError> {
+    let mut tensor_cache = tensor_cache;
+    parse_compiler_repr_bijection(
+        string,
+        module_spec_map,
+        reference_circuits,
+        tensors_as_random,
+        tensors_as_random_device_dtype,
+        &mut tensor_cache,
+    )
+}
+
 pub fn parse_compiler_repr_bijection(
     string: &str,
     module_spec_map: HashMap<String, ModuleNodeSpec>,
     reference_circuits: HashMap<String, CircuitRc>,
     tensors_as_random: bool,
     tensors_as_random_device_dtype: TorchDeviceDtypeOp,
+    tensor_cache: &mut Option<TensorCacheRrfs>,
 ) -> Result<CircuitRc, CircuitConstructionError> {
     let string = string.trim();
     let lines: Vec<_> = string.lines().collect();
@@ -141,6 +165,7 @@ pub fn parse_compiler_repr_bijection(
         reference_circuits: &HashMap<String, CircuitRc>,
         tensors_as_random: bool,
         tensors_as_random_device_dtype: TorchDeviceDtypeOp,
+        tensor_cache: &mut Option<TensorCacheRrfs>,
     ) -> CircResult {
         if let Some(already) = context.get(&serial_number) {
             return Ok(already.clone());
@@ -163,6 +188,7 @@ pub fn parse_compiler_repr_bijection(
                     reference_circuits,
                     tensors_as_random,
                     tensors_as_random_device_dtype.clone(),
+                    tensor_cache,
                 )
             })
             .collect::<Result<Vec<_>, _>>()?;
@@ -181,7 +207,7 @@ pub fn parse_compiler_repr_bijection(
                     )
                     .rc())
                 } else {
-                    ArrayConstant::from_hash_prefix(ps.name.clone(), &ps.extra)
+                    ArrayConstant::from_hash_prefix(ps.name.clone(), &ps.extra, tensor_cache)
                         .map(|z| z.rc())
                         .map_err(|e| CircuitConstructionError::PythonError {
                             py_err: Arc::new(e),
@@ -256,13 +282,13 @@ pub fn parse_compiler_repr_bijection(
             }
             "Index" => Index::try_new(
                 children[0].clone(),
-                TensorIndex::from_bijection_string(&ps.extra)?,
+                TensorIndex::from_bijection_string(&ps.extra, tensor_cache)?,
                 ps.name.clone(),
             )
             .map(|z| z.rc()),
             "Scatter" => Scatter::try_new(
                 children[0].clone(),
-                TensorIndex::from_bijection_string(&ps.extra)?,
+                TensorIndex::from_bijection_string(&ps.extra, tensor_cache)?,
                 ps.shape
                     .as_ref()
                     .ok_or(CircuitConstructionError::ParsingShapeNeeded {
@@ -354,5 +380,6 @@ pub fn parse_compiler_repr_bijection(
         &reference_circuits,
         tensors_as_random,
         tensors_as_random_device_dtype,
+        tensor_cache,
     )
 }
