@@ -30,13 +30,12 @@ pub fn scatter_fuse(scatter: &Scatter) -> Option<Scatter> {
     if let Circuit::Scatter(inner) = &**scatter.node {
         let index_composed = compose(&inner.index, &scatter.index)?;
         Some(
-            Scatter::try_new(
+            Scatter::new(
                 inner.node.clone(),
                 index_composed,
                 scatter.info().shape.clone(),
                 scatter.name_cloned(),
-            )
-            .unwrap(),
+            ),
         )
     } else {
         None
@@ -104,33 +103,25 @@ pub fn einsum_pull_scatter(einsum: &Einsum) -> Option<CircuitRc> {
                     let index =
                         uslices_shrink_base(&index_orig_base, &inner.index.all_uslices().unwrap());
                     (
-                        Index::try_new(inner.node.clone(), uslices_to_index(&index), None)
-                            .unwrap()
-                            .rc(),
+                        Index::nrc(inner.node.clone(), uslices_to_index(&index), None),
                         ints.clone(),
                     )
                 }
                 _ => (
-                    Index::try_new(node.clone(), uslice_map_get_index(ints, &int_slices), None)
-                        .unwrap()
-                        .rc(),
+                    Index::nrc(node.clone(), uslice_map_get_index(ints, &int_slices), None),
                     ints.clone(),
                 ),
             })
             .collect();
-        let new_einsum = Einsum::try_new(new_args, einsum.out_axes.clone(), einsum.name_cloned())
-            .unwrap()
-            .rc();
+        let new_einsum = Einsum::nrc(new_args, einsum.out_axes.clone(), einsum.name_cloned());
         Some(
-            Scatter::try_new(
+            Scatter::nrc(
                 new_einsum,
                 uslice_map_get_index(&einsum.out_axes, &int_slices)
                     .canonicalize(&einsum.info().shape),
                 einsum.info().shape.clone(),
                 None,
-            )
-            .unwrap()
-            .rc(),
+            ),
         )
     }
 }
@@ -192,18 +183,17 @@ pub fn add_pull_scatter(add: &Add) -> Option<Scatter> {
                         })
                         .collect(),
                 );
-                Index::try_new(node.clone(), index, None).unwrap().rc()
+                Index::nrc(node.clone(), index, None)
             })
             .collect();
-        let new_add = Add::try_new(new_operands, add.name_cloned()).unwrap().rc();
+        let new_add = Add::nrc(new_operands, add.name_cloned());
         Some(
-            Scatter::try_new(
+            Scatter::new(
                 new_add,
                 uslices_to_index(&(0..add.info().rank()).map(|i| slices[i]).collect()),
                 add.info().shape.clone(),
                 None,
-            )
-            .unwrap(),
+            ),
         )
     }
 }
@@ -256,21 +246,17 @@ pub fn index_einsum_to_scatter(node: &Index) -> Option<CircuitRc> {
                 .iter()
                 .map(|(node, ints)| {
                     (
-                        Index::try_new(node.clone(), uslice_map_get_index(ints, &int_slices), None)
-                            .unwrap()
-                            .rc(),
+                        Index::nrc(node.clone(), uslice_map_get_index(ints, &int_slices), None),
                         ints.clone(),
                     )
                 })
                 .collect();
-            let new_einsum = Einsum::try_new(new_args, inner.out_axes.clone(), inner.name_cloned())
-                .unwrap()
-                .rc();
+            let new_einsum = Einsum::nrc(new_args, inner.out_axes.clone(), inner.name_cloned());
             let new_shape = containing_uslices
                 .iter()
                 .map(|x| x.unwrap().stop - x.unwrap().start)
                 .collect();
-            let new_scatter = Scatter::try_new(
+            let new_scatter = Scatter::nrc(
                 new_einsum,
                 TensorIndex(
                     inner
@@ -288,11 +274,9 @@ pub fn index_einsum_to_scatter(node: &Index) -> Option<CircuitRc> {
                 .canonicalize(&new_shape),
                 new_shape,
                 None,
-            )
-            .unwrap()
-            .rc();
+            );
             Some(
-                Index::try_new(
+                Index::nrc(
                     new_scatter,
                     TensorIndex(
                         node.index
@@ -305,9 +289,7 @@ pub fn index_einsum_to_scatter(node: &Index) -> Option<CircuitRc> {
                             .collect(),
                     ),
                     None,
-                )
-                .unwrap()
-                .rc(),
+                ),
             )
         }
     } else {
@@ -335,8 +317,8 @@ pub fn scatter_pull_removable_axes(scatter: &Scatter) -> Option<Rearrange> {
     } else {
         let new_inner = remove_axes(&scatter.node, &removable_axes).unwrap();
         Some(
-            Rearrange::try_new(
-                Scatter::try_new(
+            Rearrange::new(
+                Scatter::nrc(
                     new_inner,
                     TensorIndex(filter_out_idx(&scatter.index.0, &removable_axes)),
                     filter_out_idx(
@@ -346,13 +328,11 @@ pub fn scatter_pull_removable_axes(scatter: &Scatter) -> Option<Rearrange> {
                     .into_iter()
                     .collect(),
                     None,
-                )
-                .unwrap()
-                .rc(),
+                ),
                 RearrangeSpec::unremove_axes(&removable_axes, &scatter.info().shape),
                 None,
             )
-            .unwrap(),
+            ,
         )
     }
 }
@@ -367,7 +347,7 @@ pub fn scatter_to_concat(scatter: &Scatter) -> CircuitRc {
         lower_pad_shape[i] = idx.start;
         let mut upper_pad_shape: Shape = result.info().shape.clone();
         upper_pad_shape[i] = l - idx.stop;
-        result = Concat::try_new(
+        result = Concat::nrc(
             vec![
                 ScalarConstant::new(0.0, lower_pad_shape, None).rc(),
                 result,
@@ -375,9 +355,7 @@ pub fn scatter_to_concat(scatter: &Scatter) -> CircuitRc {
             ],
             i,
             None,
-        )
-        .unwrap()
-        .rc();
+        );
     }
     result
 }
@@ -423,5 +401,5 @@ pub fn concat_to_scatter(concat: &Concat) -> Option<Scatter> {
     if new_concat.info().numel() == concat.info().numel() {
         return None;
     }
-    Some(Scatter::try_new(new_concat, scatter_index, concat.info().shape.clone(), None).unwrap())
+    Some(Scatter::new(new_concat, scatter_index, concat.info().shape.clone(), None))
 }
