@@ -627,7 +627,7 @@ impl EinsumSpec {
     }
 
     pub fn symbol_circuit(&self) -> Einsum {
-        Einsum::try_new(
+        Einsum::new(
             self.input_ints
                 .iter()
                 .map(|ints| {
@@ -644,7 +644,6 @@ impl EinsumSpec {
             self.output_ints.iter().map(|i| *i as u8).collect(),
             None,
         )
-        .unwrap()
     }
 }
 
